@@ -6,13 +6,16 @@ class Confirmation:
     _CONFIRM_BAD = ('', 'n', 'N')
     _CONFIRM_KNOWN = _CONFIRM_GOOD + _CONFIRM_BAD
 
-    def __init__(self, ask):
+    def __init__(self, messenger, ask):
+        self._messenger = messenger
         self._ask = ask
 
     def confirmed(self, question):
         if not self._ask:
             return True
 
+        question = self._messenger.format_question(question)
+
         while True:
             reply = input(f'{question} [y/N] ')
             if reply in self._CONFIRM_KNOWN:
